Watson-Di
=========

Watson Di is a simple dependency injection container that can store and
retrieve dependencies.

For full documentation please see `Read The
Docs <http://watson-di.readthedocs.org/>`__.

Build Status
^^^^^^^^^^^^

|Build Status| |Coverage Status| |Version| |Downloads| |Licence|

Installation
------------

``pip install watson-di``

Dependencies
------------

-  watson-common
-  watson-events

.. |Build Status| image:: https://api.travis-ci.org/watsonpy/watson-di.png?branch=master
   :target: https://travis-ci.org/watsonpy/watson-di
.. |Coverage Status| image:: https://coveralls.io/repos/watsonpy/watson-di/badge.png
   :target: https://coveralls.io/r/watsonpy/watson-di
.. |Version| image:: https://pypip.in/v/watson-di/badge.png
   :target: https://pypi.python.org/pypi/watson-di/
.. |Downloads| image:: https://pypip.in/d/watson-di/badge.png
   :target: https://pypi.python.org/pypi/watson-di/
.. |Licence| image:: https://pypip.in/license/watson-di/badge.png
   :target: https://pypi.python.org/pypi/watson-di/
